==> 0.5.33.tar.gz: lib/http/easy_dio.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:dio/adapter.dart';
import 'package:dio/dio.dart';
import 'package:dio_logger/dio_logger.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'exception/http_error.dart';
import 'http_data.dart';


/// 请求方法.
class Method {
  static final String get = "GET";
  static final String post = "POST";
  static final String put = "PUT";
  static final String head = "HEAD";
  static final String delete = "DELETE";
  static final String patch = "PATCH";
}


class EasyDio {

  //服务器路径

  static EasyDio _instance = EasyDio._internal();

  Dio _dio;

  factory EasyDio() => _instance;

  BaseOptions _baseOptions;

  Function _onError;

  Function _onFinish;

  Function _onStart;

  Function(HttpData httpData) _handleError;

  ValidateResponse _validateResponse;

  String _successCode;

  String _codeKey;

  String _msgKey;

  String _dataKey;

  Dio get dio => _dio;

  ///-----------------------------------------工具类初始化设置-------------------------------------

  EasyDio._internal();

  ///初始化公共属性
  ///
  /// [baseUrl] 地址前缀
  /// [connectTimeout] 连接超时赶时间
  /// [receiveTimeout] 接收超时赶时间
  /// [interceptors] 基础拦截器
  void init({String baseUrl,
    int connectTimeout,
    int receiveTimeout,
    String pem,
    String pKCSPath,
    String pKCSPwd,
    String codeKey = 'code',
    String msgKey = 'msg',
    String dataKey = 'data',
    String successCode = '0',
    ResponseType responseType,
    bool openLog = true,
    int retry = 3,
    String method,
    Map<String, dynamic> headers,
    Map<String, dynamic> extra,
    String contentType,
    ValidateStatus validateStatus,
    bool followRedirects,
    Function onError,
    Function onFinish,
    Function onStart,
    ValidateResponse validateResponse,
    bool enableAutoCookie = false,
    ListFormat listFormat,
    Function(HttpData httpData) handleError,
    List<Interceptor> interceptors
  }) {

    this._validateResponse = validateResponse;
    this._onStart = onStart;
    this._onError = onError;
    this._onFinish = onFinish;
    this._successCode = successCode;
    this._codeKey = codeKey;
    this._msgKey = msgKey;
    this._dataKey = dataKey;
    this._handleError = handleError;

    method = method??Method.post;

    _baseOptions = BaseOptions(
      baseUrl: baseUrl,
      receiveTimeout: receiveTimeout,
      connectTimeout: connectTimeout,
      contentType: contentType,
      responseType: responseType??ResponseType.json,
      headers: headers??{},
      extra: extra??{},
      validateStatus: validateStatus,
      followRedirects: followRedirects,
      listFormat: listFormat,
      method: method
    );


    _dio = Dio(_baseOptions);


    if(openLog && isInDebugMode){
      _dio.interceptors.add(dioLoggerInterceptor);
    }


    if (retry != 0) {
      // dio.interceptors.add(element)
      // dio.interceptors.add(RetryInterceptor(
      //     dio: dio,
      //     options: RetryOptions(
      //       retries: retry, // Number of retries before a failure
      //       retryInterval: const Duration(seconds: 1), // Interval between each retry
      //     )
      // ));
    }



    ///-----------------------------------------证书相关信息-------------------------------------
    (_dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
      client.badCertificateCallback = (X509Certificate cert, String host, int port) {
        if (isNotEmpty(pem)) {
          if (cert.pem == pem) {
            // 证书一致，则放行
            return true;
          }else{
            return false;
          }
        }else{
          return true;
        }
      };
    };

    if (isNotEmpty(pKCSPath) && isNotEmpty(pKCSPwd)) {
      (_dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
        SecurityContext sc = new SecurityContext();
        //file为证书路径
        sc.setTrustedCertificates(pKCSPath, password: pKCSPwd);
        HttpClient httpClient = new HttpClient(context: sc);
        return httpClient;
      };
    }


  }




  ///-----------------------------------------请求方法封装-------------------------------------
  Future<HttpData> request({
    String url,
    String method,
    Options options,
    String cacheKey,
    bool isFormData = false,
    bool publicMethod = true,
    var data,
    String contentType,
    CancelToken cancelToken,
    Function onStart,
    Function onError,
    Function onFinish,
    ValidateResponse validateResponse,
    String successCode,
    String codeKey,
    String msgKey,
    String dataKey,
    ProgressCallback onReceiveProgress,
    ProgressCallback onSendProgress,
    dynamic Function(Map map) handleRes,
    HttpError Function(dynamic data) validateError,
  }) async{


    HttpData _httpData = HttpData();
    String _code;
    String _msg;
    var _resultData;

    try{
      if (onStart != null){
        onStart();
      }else if(this._onStart != null){
        if (publicMethod) {
          this._onStart();
        }
      }


      Response response;

      Options mOptions = Options();

      if(isNotEmpty(options)){
        mOptions = options;
      }

      if (isFormData) {
        data = FormData.fromMap(data);
      }

      if(isNotEmpty(method)){
        mOptions.method =  method;
      }else{
        mOptions.method = _baseOptions.method;
      }


      if (method == Method.get) {
        response = await _dio.request(
            url,
            queryParameters: data,
            options: mOptions,
            cancelToken: cancelToken,
            onReceiveProgress: (int sent, int total){
              onReceiveProgress?.call(sent, total);
            },
            onSendProgress: (int sent, int total){
              onSendProgress?.call(sent, total);
            }
        );
      }else{
        response = await _dio.request(
            url,
            data: data,
            options: mOptions,
            cancelToken: cancelToken,
            onReceiveProgress: (int sent, int total){
              onReceiveProgress?.call(sent, total);
            },
            onSendProgress: (int sent, int total){
              onSendProgress?.call(sent, total);
            }
        );
      }



      String mCodeKey = codeKey??_codeKey;
      String mMsgKey = msgKey??_msgKey;
      String mDataKey = dataKey??_dataKey;
      String mSuccessCode = successCode??_successCode;


      if (response.data is List) {
        _resultData = response.data;
        _code = successCode??_successCode;
      }else{
        Map<String, dynamic> resJson;

        try{
          if(response.data is Map){
            resJson = response.data;
          }else{
            resJson = json.decode(response.data);
          }
        }catch(e){
          throw HttpError.parseDataError(e);
        }

        if(resJson.containsKey(mCodeKey)){
          _code = resJson[mCodeKey].toString();
        }

        if(resJson.containsKey(mMsgKey)){
          _msg = resJson[mMsgKey].toString();
        }


        if (isNotEmpty(validateResponse)) {
          _resultData = validateResponse(response.data);
        }else if(isNotEmpty(_validateResponse)){
          _resultData = _validateResponse(response.data);
        }



        if(_code != mSuccessCode){
          throw HttpError(HttpErrorType.ResultError, isNotEmpty(_msg)? _msg : HTTP_INCORRECT_MSG, logMsg: '请求code错误，成功code: $mSuccessCode, 请求code: $_code');
        }else{
          if(resJson.containsKey(mDataKey)){
            _resultData = resJson[mDataKey];

            if(isNotEmpty(handleRes)){
              try{
                if(_resultData is List){
                  _resultData = _resultData.map((e) => handleRes(e)).toList();
                }else if(data is Map){
                  _resultData = handleRes(data);
                }
              }catch(e){
                throw HttpError.parseDataError(e);
              }
            }

            if(isEmpty(_resultData)){
              throw HttpError.emptyDataError(_resultData);
            }
          }else{
            throw HttpError.emptyDataError(_resultData);
          }
        }
      }
    }catch(e){
      HttpError error;
      if (e is DioError) {
        error = HttpError.dioError(e);
      }else if(e is HttpError){
        error = e;
      }else{
        error = HttpError.unknown(e);
      }

      if(onError != null){
        onError.call(error);
      }else if (this._onError != null) {
        if (publicMethod) {
          this._onError.call(error);
        }
      }
      _httpData.httpError = error;

      if(isNotEmpty(validateError) && isEmpty( _httpData.httpError)){
        _httpData.httpError = validateError(_httpData.data);
      }


    }finally{
      if (isNotEmpty(onFinish)) {
        onFinish();
      } else if(isNotEmpty(this._onFinish) && publicMethod){
        this._onFinish();
      }
    }

    _httpData.code = _code;
    _httpData.msg = _msg;
    _httpData.data = _resultData;


    if(isNotEmpty(_handleError) && isNotEmpty(_httpData.httpError)){
      try{
        _handleError(_httpData);
      }catch(e){
        _httpData.httpError = HttpError.unknown(e);
      }
    }

    return _httpData;
  }



  ///-----------------------------------------上传文件方法封装-------------------------------------------------------------
  void fileUpload({
    MultipartFile multipartFile,
    String url,
    String filePath,
    String key = 'file',
    String fileName = '',
    FormData formData,
    ProgressCallback onSendProgress,
    ProgressCallback onReceiveProgress,
    Function onStart,
    Function onError,
    Function onFinish,
    bool publicMethod = true}) async{

    MultipartFile file = multipartFile??await MultipartFile.fromFile(filePath, filename: fileName);


    try{
      await _dio.post(
        url,
        data: formData??FormData.fromMap({
          key: file
        }),
        onSendProgress: (int sent, int total){
          onSendProgress?.call(sent, total);
        },
        onReceiveProgress: (int sent, int total){
          onReceiveProgress?.call(sent, total);
        },
      );
    }on DioError catch(e){
      throw HttpError.dioError(e);
    }catch(e){
      if (e is HttpError) {
        if(onError != null){
          onError.call(e);
        }else if (publicMethod) {
          this._onError?.call(e);
        }

        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(publicMethod){
          this._onFinish?.call();
        }
      }
    }
  }


  void filesUpload({
    List<MultipartFile> multipartFile,
    String url,
    String filePath,
    String key = 'file',
    String fileName = '',
    FormData formData,
    ProgressCallback onSendProgress,
    ProgressCallback onReceiveProgress,
    Function onStart,
    Function onError,
    Function onFinish,
    bool publicMethod = true}) async{


    try{
      await _dio.post(
        url,
        data: formData??FormData.fromMap({
          key: multipartFile
        }),
        onSendProgress: (int sent, int total){
          onSendProgress?.call(sent, total);
        },
        onReceiveProgress: (int sent, int total){
          onReceiveProgress?.call(sent, total);
        },
      );
    }on DioError catch(e){
      throw HttpError.dioError(e);
    }catch(e){
      if (e is HttpError) {
        if(onError != null){
          onError.call(e);
        }else if (publicMethod) {
          this._onError?.call(e);
        }

        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(publicMethod){
          this._onFinish?.call();
        }
      }
    }
  }


  ///-----------------------------------------下载文件方法封装-------------------------------------------------------------
  void download({
    String urlPath = '',
    String savePath = '',
    bool deleteOnError = true,
    String lengthHeader = Headers.contentLengthHeader,
    ProgressCallback onReceiveProgress,
    data,
    Map<String, dynamic> queryParameters,
    CancelToken cancelToken,
    Options options,
    Function onStart,
    Function onError,
    Function onFinish,
    bool publicMethod = true}) async{

    try{
      await _dio.download(
        urlPath,
        savePath,
        deleteOnError: deleteOnError,
        lengthHeader: lengthHeader,
        data: data,
        options: options,
        queryParameters: queryParameters,
        cancelToken: cancelToken,
        onReceiveProgress: (int sent, int total){
          onReceiveProgress?.call(sent, total);
        },
      );
    }on DioError catch(e){
      throw HttpError.dioError(e);
    }catch(e){
      if (e is HttpError) {
        if(onError != null){
          onError.call(e);
        }else if (publicMethod) {
          this._onError?.call(e);
        }

        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(publicMethod){
          this._onFinish?.call();
        }
      }
    }
  }




  ///-----------------------------------------dio部分设置-------------------------------------


  void setCookie(String cookie){
    Map<String, dynamic> _headers = new Map();
    _headers["Cookie"] = cookie;
    _dio.options.headers.addAll(_headers);

  }


  void setHeaders(Map<String, dynamic> headers){
    _dio.options.headers.addAll(headers);
  }

  void clearHeaders(Map<String, dynamic> headers){
    _dio.options.headers.clear();
  }

  ///修改默认url
  void changeBaseUrl(String baseUrl){
    _dio.options.baseUrl = baseUrl;
  }

}

==> 0.5.89.tar.gz: lib/http/easy_dio.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:dio/adapter.dart';
import 'package:dio/dio.dart';
import 'package:dio_logger/dio_logger.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'exception/http_error.dart';
import 'http_data.dart';


/// 请求方法.
class Method {
  static final String get = "GET";
  static final String post = "POST";
  static final String put = "PUT";
  static final String head = "HEAD";
  static final String delete = "DELETE";
  static final String patch = "PATCH";
}


class EasyDio {

  //服务器路径

  static EasyDio _instance = EasyDio._internal();

  Dio _dio;

  factory EasyDio() => _instance;

  BaseOptions _baseOptions;

  Function _onError;

  Function _onFinish;

  Function _onStart;

  ValidateResponse _validateResponse;

  String _successCode;

  String _codeKey;

  String _msgKey;

  String _dataKey;

  Dio get dio => _dio;

  List<String> publicErrorCode = [];

  ///-----------------------------------------工具类初始化设置-------------------------------------

  EasyDio._internal();

  ///初始化公共属性
  ///
  /// [baseUrl] 地址前缀
  /// [connectTimeout] 连接超时赶时间
  /// [receiveTimeout] 接收超时赶时间
  /// [interceptors] 基础拦截器
  void init({String baseUrl,
    int connectTimeout,
    int receiveTimeout,
    String pem,
    String pKCSPath,
    String pKCSPwd,
    String codeKey = 'code',
    String msgKey = 'msg',
    String dataKey = 'data',
    String successCode = '0',
    ResponseType responseType,
    bool openLog = true,
    int retry = 3,
    String method,
    Map<String, dynamic> headers,
    Map<String, dynamic> extra,
    String contentType,
    ValidateStatus validateStatus,
    bool followRedirects,
    Function onError,
    Function onFinish,
    Function onStart,
    ValidateResponse validateResponse,
    bool enableAutoCookie = false,
    ListFormat listFormat,
    List<String> publicErrorCode,
    List<Interceptor> interceptors
  }) {

    this._validateResponse = validateResponse;
    this._onStart = onStart;
    this._onError = onError;
    this._onFinish = onFinish;
    this._successCode = successCode;
    this._codeKey = codeKey;
    this._msgKey = msgKey;
    this._dataKey = dataKey;

    method = method??Method.post;

    if(isNotEmpty(publicErrorCode)){
      this.publicErrorCode.addAll(publicErrorCode);
    }

    _baseOptions = BaseOptions(
        baseUrl: baseUrl,
        receiveTimeout: receiveTimeout,
        connectTimeout: connectTimeout,
        contentType: contentType,
        responseType: responseType??ResponseType.json,
        headers: headers??{},
        extra: extra??{},
        validateStatus: validateStatus,
        followRedirects: followRedirects,
        listFormat: listFormat,
        method: method
    );


    _dio = Dio(_baseOptions);


    if(openLog && isInDebugMode){
      _dio.interceptors.add(dioLoggerInterceptor);
    }


    if (retry != 0) {
      // dio.interceptors.add(element)
      // dio.interceptors.add(RetryInterceptor(
      //     dio: dio,
      //     options: RetryOptions(
      //       retries: retry, // Number of retries before a failure
      //       retryInterval: const Duration(seconds: 1), // Interval between each retry
      //     )
      // ));
    }



    ///-----------------------------------------证书相关信息-------------------------------------
    (_dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
      client.badCertificateCallback = (X509Certificate cert, String host, int port) {
        if (isNotEmpty(pem)) {
          if (cert.pem == pem) {
            // 证书一致，则放行
            return true;
          }else{
            return false;
          }
        }else{
          return true;
        }
      };
    };

    if (isNotEmpty(pKCSPath) && isNotEmpty(pKCSPwd)) {
      (_dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
        SecurityContext sc = new SecurityContext();
        //file为证书路径
        sc.setTrustedCertificates(pKCSPath, password: pKCSPwd);
        HttpClient httpClient = new HttpClient(context: sc);
        return httpClient;
      };
    }


  }




  ///-----------------------------------------请求方法封装-------------------------------------
  Future<HttpData> request({
    String url,
    String method,
    Options options,
    String cacheKey,
    bool isFormData,
    bool publicMethod,
    var data,
    String contentType,
    CancelToken cancelToken,
    Function onStart,
    Function(HttpData httpData) onSuccess,
    Function(HttpData httpData) onError,
    Function onFinish,
    ValidateResponse validateResponse,
    String successCode,
    String codeKey,
    String msgKey,
    String dataKey,
    ProgressCallback onReceiveProgress,
    ProgressCallback onSendProgress,
    dynamic Function(Map map) handleRes,
    HttpError Function(dynamic data) validateError,
  }) async{


    HttpData _httpData = HttpData();
    String _code;
    String _msg;
    var _resultData;

    publicMethod = publicMethod??true;
    isFormData = isFormData??false;

    try{

      if(onStart != null){
        onStart.call();
      }else if(publicMethod && this._onStart != null) {
        this._onStart();
      }


      Response response;

      Options mOptions = Options();

      if(isNotEmpty(options)){
        mOptions = options;
      }

      if (isFormData) {
        data = FormData.fromMap(data);
      }

      if(isNotEmpty(method)){
        mOptions.method =  method;
      }else{
        mOptions.method = _baseOptions.method;
      }


      if (method == Method.get) {
        response = await _dio.request(
            url,
            queryParameters: data,
            options: mOptions,
            cancelToken: cancelToken,
            onReceiveProgress: (int sent, int total){
              onReceiveProgress?.call(sent, total);
            },
            onSendProgress: (int sent, int total){
              onSendProgress?.call(sent, total);
            }
        );
      }else{
        response = await _dio.request(
            url,
            data: data,
            options: mOptions,
            cancelToken: cancelToken,
            onReceiveProgress: (int sent, int total){
              onReceiveProgress?.call(sent, total);
            },
            onSendProgress: (int sent, int total){
              onSendProgress?.call(sent, total);
            }
        );
      }



      String mCodeKey = codeKey??_codeKey;
      String mMsgKey = msgKey??_msgKey;
      String mDataKey = dataKey??_dataKey;
      String mSuccessCode = successCode??_successCode;


      if (response.data is List) {
        _resultData = response.data;
        _code = successCode??_successCode;
      }else{
        Map<String, dynamic> resJson;

        try{
          if(response.data is Map){
            resJson = response.data;
          }else{
            resJson = json.decode(response.data);
          }
        }catch(e){
          throw HttpError.parseDataError(e);
        }

        if(resJson.containsKey(mCodeKey)){
          _code = resJson[mCodeKey].toString();
        }

        if(resJson.containsKey(mMsgKey)){
          _msg = resJson[mMsgKey].toString();
        }


        if (isNotEmpty(validateResponse)) {
          _resultData = validateResponse(response.data);
        }else if(isNotEmpty(_validateResponse)){
          _resultData = _validateResponse(response.data);
        }



        if(_code != mSuccessCode){
          throw HttpError(HttpErrorType.ResultError, isNotEmpty(_msg)? _msg : HTTP_INCORRECT_MSG, logMsg: '请求code错误，成功code: $mSuccessCode, 请求code: $_code');
        }else{
          if(resJson.containsKey(mDataKey)){
            _resultData = resJson[mDataKey];

            if(isNotEmpty(handleRes)){
              try{
                if(_resultData is List){
                  _resultData = _resultData.map((e) => handleRes(e)).toList();
                }else if(_resultData is Map){
                  _resultData = handleRes(_resultData);
                }
              }catch(e){
                throw HttpError.parseDataError(e);
              }
            }

            if(isEmpty(_resultData)){
              throw HttpError.emptyDataError(_resultData);
            }
          }else{
            throw HttpError.emptyDataError(_resultData);
          }
        }
      }
    }catch(e){
      HttpError error;
      if (e is DioError) {
        error = HttpError.dioError(e);
      }else if(e is HttpError){
        error = e;
      }else{
        error = HttpError.unknown(e);
      }
      _httpData.httpError = error;

    }

    _httpData.code = _code;
    _httpData.msg = _msg;
    _httpData.data = _resultData;


    try{
      if(isNotEmpty(_httpData.httpError)){
        if(isNotEmpty(validateError)){
          _httpData.httpError = validateError(_httpData.data);
        }

        if(onError != null){
          onError.call(_httpData);
          if(publicErrorCode.contains(_code)){
            if (this._onError != null) {
              this._onError.call(_httpData);
            }
          }
        }else if(publicMethod && this._onError != null) {
          this._onError.call(_httpData);
        }
      }else{
        onSuccess?.call(_httpData);
      }


      if(onFinish != null){
        onFinish.call();
      }else if(publicMethod && this._onFinish != null) {
        this._onFinish.call();
      }

    }catch(e){
      _httpData.httpError = HttpError.unknown(e);
    }


    return _httpData;
  }



  ///-----------------------------------------上传文件方法封装-------------------------------------------------------------
  Future<HttpData> fileUpload({
    MultipartFile multipartFile,
    String url,
    String filePath,
    String key = 'file',
    String fileName,
    FormData formData,
    ProgressCallback onSendProgress,
    ProgressCallback onReceiveProgress,
    Function onStart,
    Function onError,
    Function onFinish,
    bool publicMethod = false}) async{

    MultipartFile file = multipartFile??await MultipartFile.fromFile(filePath, filename: fileName);

    return await request(
      url: url,
      method: Method.post,
      publicMethod: publicMethod,
      data: formData??FormData.fromMap({
        key: file
      }),
      onSendProgress: (int sent, int total){
        onSendProgress?.call(sent, total);
      },
      onReceiveProgress: (int sent, int total){
        onReceiveProgress?.call(sent, total);
      },
    );

  }


  Future<HttpData> filesUpload({
    List<MultipartFile> multipartFile,
    String url,
    String filePath,
    String key = 'file',
    String fileName,
    FormData formData,
    ProgressCallback onSendProgress,
    ProgressCallback onReceiveProgress,
    Function onStart,
    Function onError,
    Function onFinish,
    bool publicMethod = false}) async{


    return await request(
      url: url,
      method: Method.post,
      publicMethod: publicMethod,
      data: formData??FormData.fromMap({
        key: multipartFile
      }),
      onSendProgress: (int sent, int total){
        onSendProgress?.call(sent, total);
      },
      onReceiveProgress: (int sent, int total){
        onReceiveProgress?.call(sent, total);
      },
    );
  }


  ///-----------------------------------------下载文件方法封装-------------------------------------------------------------
  void download({
    String urlPath = '',
    String savePath = '',
    bool deleteOnError = true,
    String lengthHeader = Headers.contentLengthHeader,
    ProgressCallback onReceiveProgress,
    data,
    Map<String, dynamic> queryParameters,
    CancelToken cancelToken,
    Options options,
    Function onStart,
    Function onError,
    Function onFinish,
    bool publicMethod = true}) async{

    try{
      await _dio.download(
        urlPath,
        savePath,
        deleteOnError: deleteOnError,
        lengthHeader: lengthHeader,
        data: data,
        options: options,
        queryParameters: queryParameters,
        cancelToken: cancelToken,
        onReceiveProgress: (int sent, int total){
          onReceiveProgress?.call(sent, total);
        },
      );
    }on DioError catch(e){
      throw HttpError.dioError(e);
    }catch(e){
      if (e is HttpError) {
        if(onError != null){
          onError.call(e);
        }else if (publicMethod) {
          this._onError?.call(e);
        }

        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(publicMethod){
          this._onFinish?.call();
        }
      }
    }
  }




  ///-----------------------------------------dio部分设置-------------------------------------


  void setCookie(String cookie){
    Map<String, dynamic> _headers = new Map();
    _headers["Cookie"] = cookie;
    _dio.options.headers.addAll(_headers);

  }


  void setHeaders(Map<String, dynamic> headers){
    _dio.options.headers.addAll(headers);
  }

  void clearHeaders(Map<String, dynamic> headers){
    _dio.options.headers.clear();
  }

  ///修改默认url
  void changeBaseUrl(String baseUrl){
    _dio.options.baseUrl = baseUrl;
  }

}
